##  Step 1: Generate SBOMs
You can generate SBOMs at various stages of your Software Development Lifecycle (SDLC), including container registries, CI/CD pipelines, security tooling, and Source Control Management (SCM) tools like GitLab, Bitbucket, and GitHub. For guidance on generating SBOMs, refer to [Generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Explore the requirements for SBOM files and get an overview of the methods for generating them.").
**Note**
For the CycloneDX format, only SBOM components of the type [library![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcyclonedx.org%2Fdocs%2F1.6%2Fjson%2F%23components_items_type "https://cyclonedx.org/docs/1.6/json/#components_items_type") can be processed. If you're using other component types that are not supported, please [submit your feedback![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2F "https://roadmap.leanix.net/").
